#
# spec file for package istioctl
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           istioctl
Version:        1.19.0
Release:        1.1
Summary:        CLI for the istio servic mesh in Kubernetes
License:        Apache-2.0
URL:            https://github.com/istio/istio
Source:         istio-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  fdupes
BuildRequires:  go >= 1.19

%description
The istioctl tool is a configuration command line utility that allows service operators to debug and diagnose their Istio service mesh deployments. The Istio project also includes two helpful scripts for istioctl that enable auto-completion for Bash and ZSH. Both of these scripts provide support for the currently available istioctl commands.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%setup -q -n istio-%{version}
%setup -q -T -D -a1 -n istio-%{version}

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X istio.io/pkg/version.buildVersion=%{version} -X istio.io/pkg/version.buildArch=${GOARCH} -X istio.io/pkg/version.buildOS=linux" \
   -o bin/%{name} ./istioctl/cmd/istioctl

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# copy the sample files
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -vr samples %{buildroot}%{_docdir}/%{name}
rm -f %{buildroot}%{_docdir}/%{name}/samples/bookinfo/src/reviews/.gitignore
rm -f %{buildroot}%{_docdir}/%{name}/samples/bookinfo/src/reviews/reviews-wlpcfg/shared/.gitkeep
rm -f %{buildroot}%{_docdir}/%{name}/samples/wasm_modules/header_injector/.gitignore
%fdupes %{buildroot}%{_docdir}/%{name}/samples/

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_docdir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 1.19.0:
  very large changelog, please find it at
  https://github.com/istio/istio/releases/tag/1.19.0 and
  https://istio.io/news/releases/1.19.x/announcing-1.19/
* Tue Jul 25 2023 kastl@b1-systems.de
- Update to version 1.18.2:
  * Add validation of workload entry identity (#117)
  * Bump proxy version (#122)
  * Automator: update proxy@release-1.18 in
    istio/istio@release-1.18 (#46039)
  * Automator: update proxy@release-1.18 in
    istio/istio@release-1.18 (#46025)
  * Fix nil map for cluster builder (#46024)
  * fix concurrent map access in endpoint metadata (#44473)
    (#46021)
  * fix conflict (#46017)
  * Exit if sds socket not found (#45941) (#46014)
* Mon Jul 17 2023 kastl@b1-systems.de
- Update to version 1.18.1:
  * Automator: update proxy@release-1.18 in
    istio/istio@release-1.18 (#46007)
  * Automator: update ztunnel@release-1.18 in
    istio/istio@release-1.18 (#46000)
  * Automator: update istio/client-go@release-1.18 dependency in
    istio/istio@release-1.18 (#45996)
  * Automator: update common-files@release-1.18 in
    istio/istio@release-1.18 (#45995)
  * Update image from (#45958)
  * [release-1.18] prevent port conflict with sidecar static
    listener like 15021 15090 (#45966)
  * [release-1.18] Set inject true for compatibility tests (#45928)
  * Automator: update ztunnel@release-1.18 in
    istio/istio@release-1.18 (#45948)
  * Add release note for #45632 (#45927)
  * [release-1.18] Fix health probe port overwrite (#45873)
  * Automator: update istio/client-go@release-1.18 dependency in
    istio/istio@release-1.18 (#45938)
  * Automator: update common-files@release-1.18 in
    istio/istio@release-1.18 (#45936)
  * Automator: update ztunnel@release-1.18 in
    istio/istio@release-1.18 (#45892)
  * Automator: update common-files@release-1.18 in
    istio/istio@release-1.18 (#45875)
  * Automator: update istio/client-go@release-1.18 dependency in
    istio/istio@release-1.18 (#45876)
  * [release-1.18] Fix bug report include option not working as
    expected (#45860)
  * Automator: update istio/client-go@release-1.18 dependency in
    istio/istio@release-1.18 (#45857)
  * [release-1.18] Fix a potential nil panic of endpointindex
    (#45808)
  * Automator: update proxy@release-1.18 in
    istio/istio@release-1.18 (#45834)
  * Automator: update proxy@release-1.18 in
    istio/istio@release-1.18 (#45771)
  * Automator: update proxy@release-1.18 in
    istio/istio@release-1.18 (#45769)
  * Automator: update proxy@release-1.18 in
    istio/istio@release-1.18 (#45747)
  * gcp metadata: compute GCPClusterURL from metadata (#45741)
  * Fix auth header syntax (#45711)
  * Automator: update ztunnel@release-1.18 in
    istio/istio@release-1.18 (#45702)
  * Bump github.com/lestrrat-go/jwx from 1.2.25 to 1.2.26 (#45684)
  * Automator: update common-files@release-1.18 in
    istio/istio@release-1.18 (#45690)
  * Automator: update istio/client-go@release-1.18 dependency in
    istio/istio@release-1.18 (#45660)
  * Automator: update proxy@release-1.18 in
    istio/istio@release-1.18 (#45667)
  * prow: move to use WI for auth_header in private (#45609)
  * Automator: update proxy@release-1.18 in
    istio/istio@release-1.18 (#45587)
  * Automator: update ztunnel@release-1.18 in
    istio/istio@release-1.18 (#45579)
  * Automator: update istio/client-go@release-1.18 dependency in
    istio/istio@release-1.18 (#45570)
  * Automator: update common-files@release-1.18 in
    istio/istio@release-1.18 (#45569)
  * [release-1.18] improve accesslog mode e2e tests (#45519)
  * Update BASE_VERSION to 1.18-2023-06-15T19-02-54 (#45495)
  * [release-1.18] cherry-pick: add debug info when generating
    certs for workloads (#45194)
  * [release-1.18] Update min supported k8s version to 1.24
    (#45444)
  * Automator: update proxy@release-1.18 in
    istio/istio@release-1.18 (#45450)
  * Automator: update istio/client-go@release-1.18 dependency in
    istio/istio@release-1.18 (#45381)
  * [release-1.18] Check the disabled status when adding a log
    provider (#45373)
  * Change to use Node instead of RawMeta (#45359)
  * [release-1.18] Fix istioctl pc secret cert validity not
    accurate (#45343)
  * Add rolling update max unavailable to CNI chart to speed up
    deploys (cherry pick to release-1.18) (#44934)
  * Fix Telemetry disablement matching (#45303)
  * Fix invalid XDS configuration for wildcard Ingress HTTP path
    (#44898) (#45168)
  * Adding LRS support (#45165)
  * [release-1.18] Certificate Revocation List support (#45130)
  * [release-1.18]Manual cherry-pick of 44481 and 44775 (#45081)
  * precise-errorcode-debuggen (#45164)
  * Automator: update ztunnel@release-1.18 in
    istio/istio@release-1.18 (#45333)
  * Automator: update istio/client-go@release-1.18 dependency in
    istio/istio@release-1.18 (#45326)
  * Automator: update common-files@release-1.18 in
    istio/istio@release-1.18 (#45325)
* Tue Jun 13 2023 kastl@b1-systems.de
- Update to version 1.18.0:
  very large changelog, please see
  https://istio.io/latest/news/releases/1.18.x/announcing-1.18/
* Tue Jun 13 2023 kastl@b1-systems.de
- Update to version 1.17.3:
  * Update BASE_VERSION to 1.17-2023-05-31T19-02-43 (#45227)
  * Revert "[release-1.17] Operator: Fix webhooks reconciled by
    operator are inconsistent with istioctl install's (#45121)"
    (#45205)
  * 1.17: bump docker dep (#45198)
  * cherry-pick: add debug info when generating certs for workloads
    [#45183] (#45189)
  * [release-1.17] Run update_deps.sh (#45177)
  * [release-1.17] Operator: Fix webhooks reconciled by operator
    are inconsistent with istioctl install's (#45121)
  * RetryWithContext should use the new NextBackOff() (#45122)
  * Update BASE_VERSION to 1.17-2023-05-24T19-03-36 (#45110)
  * [release-1.17] fix backoff and read ca file interval (#45039)
  * [release-1.17]Manual cherry-pick of 44481 and 44775 (#45082)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#45017)
  * Automator: update istio/client-go@release-1.17 dependency in
    istio/istio@release-1.17 (#45070)
  * Automator: update common-files@release-1.17 in
    istio/istio@release-1.17 (#45069)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44989)
  * remove file from file certs before triggering call backs
    (#44908)
  * [release-1.17] Fix  MaybeApplyTLSModeLabel function (#44939)
  * spiffe: fix handling of trust bundles with multiple keys
    (#44909)
  * [release-1.17] inject: remove unknown fields from template
    (#44858)
  * add support for security.istio.io/v1beta1 api in authz tests
    when testing multiple istio versions (#44447) (#44808)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44782)
  * [release-1.17] Fix persistent sessions scale down with envoy
    (#44652)
  * [release-1.17] Fix verify-install to work with multi iops
    (#44753)
  * Skip runtime resources when analyzing files (#44506) (#44733)
  * [release-1.17] Fix pilot using wrong readinessprobe check,
    should check if /validate and /inject endpoints are ready.
    (#44750)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44745)
  * Fix multi-cluster issue by increasing the timeout of listing
    CRDs (#44715) (#44739)
  * Automator: update istio/client-go@release-1.17 dependency in
    istio/istio@release-1.17 (#44734)
  * Automator: update common-files@release-1.17 in
    istio/istio@release-1.17 (#44732)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44718)
  * Use safer dedupe for config (#44502) (#44535)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44618)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44598)
  * Update BASE_VERSION to 1.17-2023-04-26T19-03-52 (#44574)
  * disable automount SA token only on tests with min istio
    revisions >= 1.16 (#44492)
  * fix missing gateway services (#44463)
  * [release-1.17] add validation for empty prefix header match
    (#44455)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44440)
  * Integration Test for Istio custom GRPC count metrics (#44288)
  * [release-1.17] gateway: prevent duplicate `istio_authn` network
    filter in the filter chain (#44399)
  * fix gateway service name (#44382)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44389)
  * Update BASE_VERSION to 1.17-2023-04-12T19-03-40 (#44359)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44344)
  * Automator: update istio/client-go@release-1.17 dependency in
    istio/istio@release-1.17 (#44283)
  * Automator: update common-files@release-1.17 in
    istio/istio@release-1.17 (#44282)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44271)
  * gateway: remove internal annotation from propogating (#44220)
    (#44229)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44241)
  * [release-1.17] add release-notes for grpc stats (#44222)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44217)
  * [1.17] gateway deployment controller: handle backwards
    compatibility (#44171)
  * fix: increment failures in serverFailure function (#44176)
  * [release-1.17] always enable grpc stats filter (#44180)
* Wed Apr 19 2023 Johannes Kastl <kastl@b1-systems.de>
- package sample files
* Wed Apr  5 2023 kastl@b1-systems.de
- Update to version 1.17.2:
  * [release-1.17] Update deps 1.17 (#106)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44133)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44102)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44079)
  * Add endpointslices to bug-report dump (#44054)
  * Automator: update common-files@release-1.17 in
    istio/istio@release-1.17 (#44055)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44061)
  * Automator: update istio/client-go@release-1.17 dependency in
    istio/istio@release-1.17 (#44058)
  * vm: fix assigning label from metadata (#44021)
  * [release-1.17] tracing: Update proxyConfig.Tracing merge logic
    (#42518) (#44019)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#44049)
  * Update BASE_VERSION to 1.17-2023-03-21T19-02-32 (#44039)
  * add retry to default service account patch command (#43915)
  * Fix gateway injection when istio.io/rev=<tag> (#43668)
  * Automator: update istio/client-go@release-1.17 dependency in
    istio/istio@release-1.17 (#43973)
  * [release-1.17] Fix x wait when
    PILOT_ENABLE_CONFIG_DISTRIBUTION_TRACKING is not true (#43980)
  * Automator: update common-files@release-1.17 in
    istio/istio@release-1.17 (#43971)
  * Use ReadHeaderTimeout instead of ReadTimeout when gRPC is
    multiplexed (#43885)
  * Break system namespace and ingressgateway assumptions  (#43809)
    (#43866)
  * [release-1.17] Run update_deps.sh (#43869)
  * [release-1.17] ServiceEntry IP allocation: Stable IP when used
    in multiple namespaces (#43879)
  * Bump Helm to 3.11.1 (#43860)
  * Bump x/net to 0.7.0 (#43851)
  * Automator: update istio/client-go@release-1.17 dependency in
    istio/istio@release-1.17 (#43855)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#43856)
  * Automator: update common-files@release-1.17 in
    istio/istio@release-1.17 (#43854)
  * Automator: update istio/client-go@release-1.17 dependency in
    istio/istio@release-1.17 (#43834)
  * [release-1.17] Fix name resolution in istioctl command (#43819)
  * Update BASE_VERSION to 1.17-2023-03-07T19-01-20 (#43812)
  * [release-1.17] rbac: honor useAuthenticated (#43808)
  * [release-1.17] Include trustDomains from CaCertificates in SAN
    Validation (#43795)
  * AccessLogging: fix the issue where disable accesslogging does
    not take effect. (#43798)
  * Update BASE_VERSION to 1.17-2023-03-03T19-02-38 (#43757)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#43734)
  * Automator: update istio/client-go@release-1.17 dependency in
    istio/istio@release-1.17 (#43718)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#43707)
  * Automator: update istio/client-go@release-1.17 dependency in
    istio/istio@release-1.17 (#43695)
  * [release-1.17] Fix analyzing not caught some messages in
    default namespace (#43678)
  * Update BASE_VERSION to 1.17-2023-02-28T19-03-02 (#43666)
  * [release-1.17] fix unexpected behavior of multi accesslogging
    filters (#43591)
  * [release-1.17] validate: improve ValidateHTTPHeaderValue
    (#43391)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#43573)
  * [release-1.17] cluster: clone Push.Mesh.ConnectTimeout to avoid
    unintended mutation by EnvoyFilter (#43557)
  * [release-1.17] Fix large direct response (#43550)
  * Automator: update proxy@release-1.17 in
    istio/istio@release-1.17 (#43530)
* Tue Mar 28 2023 Johannes Kastl <kastl@b1-systems.de>
- bash-completion subpackage now Requires bash-completion
* Fri Mar  3 2023 Johannes Kastl <kastl@b1-systems.de>
- new package istioctl: CLI for the istio service mesh for Kubernetes
